---
title: <span class="badge object-type-scalar"></span> TurkishLira
---
# <span class="badge object-type-scalar"></span> TurkishLira

Currency: Turkish Lira (₺)

## Definition

```python
# Currency: Turkish Lira (₺)
TurkishLira: typing.Literal["currencyTRY"] = "currencyTRY"
```
